==> csbase-login-ca-0.1.0-jpf.zip: META-INF/main/java/br/com/petrobras/security/server/service/soap/SaveApplicationEnvironment.java <==

package br.com.petrobras.security.server.service.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for saveApplicationEnvironment complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="saveApplicationEnvironment">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="messageHeader" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}soapMessageHeader" minOccurs="0"/>
 *         &lt;element name="applicationEnvironment" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}ApplicationEnvironmentDTO" minOccurs="0"/>
 *         &lt;element name="applicationEnvironmentPassword" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "saveApplicationEnvironment", propOrder = {
    "messageHeader",
    "applicationEnvironment",
    "applicationEnvironmentPassword"
})
public class SaveApplicationEnvironment {

    protected SoapMessageHeader messageHeader;
    protected ApplicationEnvironmentDTO applicationEnvironment;
    protected String applicationEnvironmentPassword;

    /**
     * Gets the value of the messageHeader property.
     * 
     * @return
     *     possible object is
     *     {@link SoapMessageHeader }
     *     
     */
    public SoapMessageHeader getMessageHeader() {
        return messageHeader;
    }

    /**
     * Sets the value of the messageHeader property.
     * 
     * @param value
     *     allowed object is
     *     {@link SoapMessageHeader }
     *     
     */
    public void setMessageHeader(SoapMessageHeader value) {
        this.messageHeader = value;
    }

    /**
     * Gets the value of the applicationEnvironment property.
     * 
     * @return
     *     possible object is
     *     {@link ApplicationEnvironmentDTO }
     *     
     */
    public ApplicationEnvironmentDTO getApplicationEnvironment() {
        return applicationEnvironment;
    }

    /**
     * Sets the value of the applicationEnvironment property.
     * 
     * @param value
     *     allowed object is
     *     {@link ApplicationEnvironmentDTO }
     *     
     */
    public void setApplicationEnvironment(ApplicationEnvironmentDTO value) {
        this.applicationEnvironment = value;
    }

    /**
     * Gets the value of the applicationEnvironmentPassword property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getApplicationEnvironmentPassword() {
        return applicationEnvironmentPassword;
    }

    /**
     * Sets the value of the applicationEnvironmentPassword property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setApplicationEnvironmentPassword(String value) {
        this.applicationEnvironmentPassword = value;
    }

}

==> csbase-login-ca-0.1.2-jpf.zip: META-INF/main/java/br/com/petrobras/security/server/service/soap/SaveApplicationEnvironment.java <==

package br.com.petrobras.security.server.service.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for saveApplicationEnvironment complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="saveApplicationEnvironment">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="messageHeader" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}soapMessageHeader" minOccurs="0"/>
 *         &lt;element name="applicationEnvironment" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}ApplicationEnvironmentKitDTO" minOccurs="0"/>
 *         &lt;element name="applicationEnvironmentPassword" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "saveApplicationEnvironment", propOrder = {
    "messageHeader",
    "applicationEnvironment",
    "applicationEnvironmentPassword"
})
public class SaveApplicationEnvironment {

    protected SoapMessageHeader messageHeader;
    protected ApplicationEnvironmentKitDTO applicationEnvironment;
    protected String applicationEnvironmentPassword;

    /**
     * Gets the value of the messageHeader property.
     * 
     * @return
     *     possible object is
     *     {@link SoapMessageHeader }
     *     
     */
    public SoapMessageHeader getMessageHeader() {
        return messageHeader;
    }

    /**
     * Sets the value of the messageHeader property.
     * 
     * @param value
     *     allowed object is
     *     {@link SoapMessageHeader }
     *     
     */
    public void setMessageHeader(SoapMessageHeader value) {
        this.messageHeader = value;
    }

    /**
     * Gets the value of the applicationEnvironment property.
     * 
     * @return
     *     possible object is
     *     {@link ApplicationEnvironmentKitDTO }
     *     
     */
    public ApplicationEnvironmentKitDTO getApplicationEnvironment() {
        return applicationEnvironment;
    }

    /**
     * Sets the value of the applicationEnvironment property.
     * 
     * @param value
     *     allowed object is
     *     {@link ApplicationEnvironmentKitDTO }
     *     
     */
    public void setApplicationEnvironment(ApplicationEnvironmentKitDTO value) {
        this.applicationEnvironment = value;
    }

    /**
     * Gets the value of the applicationEnvironmentPassword property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getApplicationEnvironmentPassword() {
        return applicationEnvironmentPassword;
    }

    /**
     * Sets the value of the applicationEnvironmentPassword property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setApplicationEnvironmentPassword(String value) {
        this.applicationEnvironmentPassword = value;
    }

}
